# latest Indonesia Earthquake
This package will get the latest earthquake info from BMKG | Meteorological, Climatological, and Geophysical Agency.
## HOW IT WORK?
This package will scrape from [BMKG](https://www.bmkg.go.id/) to get latest earthquake happened in Indonesia.

this package will use BeautifulSoup4 and Requests, which output a JSON file, which is ready to use for web and mobile applications.